@@ -12,15 +12,14 @@ struct exfat_mkfs_info {
 	unsigned int total_clu_cnt;
 	unsigned int used_clu_cnt;
 	unsigned int fat_byte_off;
-	unsigned int fat_byte_len;
-	unsigned int clu_byte_off;
-	unsigned int bitmap_byte_off;
+	unsigned long long fat_byte_len;
+	unsigned long long clu_byte_off;
+	unsigned long long bitmap_byte_off;
 	unsigned int bitmap_byte_len;
-	unsigned int ut_byte_off;
+	unsigned long long ut_byte_off;
 	unsigned int ut_start_clu;
-	unsigned int ut_clus_off;
 	unsigned int ut_byte_len;
-	unsigned int root_byte_off;
+	unsigned long long root_byte_off;
 	unsigned int root_byte_len;
 	unsigned int root_start_clu;
 	unsigned int volume_serial;
